{% extends "djobberbase/base.html" %}

{% block content %}

        <div id="content"> 
			<div id="job-listings"></div><!-- #job-listings --> 
			<div id="no-ads"> 
				<p>There are currently no available jobs for</p> 
				<p> 
										<a href="http://www.jobberbase.com/demo/post/" title="Post a new job">Post a new job</a> &middot;
					 
					<a href="http://www.jobberbase.com/demo/">Go back to category</a> 
				</p> 
			</div> 
		</div><!-- /content -->

{% endblock %}
