Hello! :)<br /><br />
Your ad was published and is available at {{job_url}}
<br /><br />---<br />Edit it: {{job_edit_url}}
<br />Deactivate it: {{job_deactivate_url}}
<br /><br />---<br />Thank you for using our service!
<br /> The {{site_name}} Team
