	{{job_url}}
    {% if job_activate_url %}
	<br /> Activate: {{job_activate_url}}
    {% endif %}
	<br /> {{job_title}} at {{job_company}}
	<br /> {{job_description}}
	<br /> URL: {{job_url}}
	<br />---<br /> Published by: {{job_poster_email}}
	<br />---<br /> Edit: {{job_edit_url}}
	<br /> Deactivate: {{job_deactivate_url}}
	<br /><br />---<br /> IP: {{job_poster_ip}}
	<br /> Date: {{job_post_date}}
